@@ -35,7 +35,7 @@ if ( !isGeneric('mapView') ) {
 #'   Set to \code{NULL} to get default leaflet behaviour where allfeatures
 #'   are rendered in the same pane and layer order is determined automatically/sequentially.
 #' @param canvas whether to use canvas rendering rather than svg. May help
-#'   performance with larger data. See \url{https://leafletjs.com/SlavaUkraini/reference.html#canvas}
+#'   performance with larger data. See \url{https://leafletjs.com/index.html#canvas}
 #'   for more information. Only applicable for vector data. The default setting will
 #'   decide automatically, based on feature complexity.
 #' @param viewer.suppress deprecated.
@@ -377,7 +377,7 @@ setMethod('mapView', signature(x = 'RasterLayer'),
   }
 
   # convert to proper "stars" if proxy, and downscale if needed
-  if (inherits(x, "stars_proxy")) {
+  if (inherits(x, c("SpatRaster", "stars_proxy"))) {
     if (!do.downscale) {
       x <-  stars::st_as_stars(x)
     } else {
@@ -452,6 +452,10 @@ setMethod('mapView', signature(x = 'stars'), .stars_method)
 setMethod('mapView', signature(x = 'stars_proxy'), .stars_method)
 
 
+#' @describeIn mapView \code{SpatRaster}
+setMethod('mapView', signature(x = 'SpatRaster'), .stars_method)
+
+
 
 ## Raster Stack/Brick ===========================================================
 #' @describeIn mapView \code{\link{stack}} / \code{\link{brick}}
@@ -587,10 +591,8 @@ setMethod('mapView', signature(x = 'Satellite'),
 ######## SIMPLE FEATURES ##################################################
 
 ## sf =====================================================================
-#' @describeIn mapView \code{\link{st_sf}}
 
-setMethod('mapView', signature(x = 'sf'),
-          function(x,
+.sf_method <- function(x,
                    map = NULL,
                    pane = "auto",
                    canvas = useCanvas(x),
@@ -620,6 +622,8 @@ setMethod('mapView', signature(x = 'sf'),
                    hide = FALSE,
                    ...) {
 
+            if(inherits(x, 'SpatVector')){x <- sf::st_as_sf(x)}
+
             if (nrow(x) == 0) {
               stop("\n", deparse(substitute(x, env = parent.frame())),
                    " does not contain data \n", call. = FALSE)
@@ -823,7 +827,14 @@ setMethod('mapView', signature(x = 'sf'),
               NULL
             }
           }
-)
+
+
+#' @describeIn mapView \code{sf}
+setMethod('mapView', signature(x = 'sf'), .sf_method)
+
+#' @describeIn mapView \code{SpatVector}
+setMethod('mapView', signature(x = 'SpatVector'), .sf_method)
+
 
 
 ## sfc ====================================================================
@@ -956,7 +967,6 @@ setMethod('mapView', signature(x = 'sfc'),
           }
 )
 
-
 ## character ==============================================================
 #' @param tms whether the tiles are served as TMS tiles.
 #'
@@ -1322,10 +1332,10 @@ setMethod('mapView', signature(x = 'list'),
                    native.crs = FALSE,
                    hide = FALSE,
                    ...) {
-# browser()
+
             if ("by_row" %in% names(list(...))) {
               listify = listifyer(x, by_row = list(...)$by_row)
-              if (unique(sapply(x, nrow)) == length(popup)) {
+              if (all(unique(sapply(x, nrow)) == length(popup))) {
                 popup = rep(list(popup), length(x))
               } else {
                 popup = listify(popup)
