@@ -77,6 +77,7 @@ leaflet_stars = function(x,
                          query.prefix,
                          viewer.suppress,
                          pane,
+                         hide,
                          ...) {
 
   if (native.crs) {
@@ -268,11 +269,25 @@ leaflet_stars = function(x,
     #                         opacity = legend.opacity,
     #                         values = at,
     #                         title = grp)
-    legend = mapviewLegend(values = as.vector(layer),
-                           colors = col.regions,
-                           at = at,
-                           na.color = col2Hex(na.color),
-                           layer.name = layer.name)
+    clrs = attr(layer, "colors")
+    if (!is.null(clrs)) {
+      clrs_levs = unique(cbind(attr(layer, "colors"), levels(layer)))
+      clrs_levs = clrs_levs[nchar(clrs_levs[, 2]) > 0, ]
+      legend = mapviewLegend(
+        values = factor(clrs_levs[, 2], levels = clrs_levs[, 2])
+        , colors = clrs_levs[, 1]
+        , at = at
+        , na.color = col2Hex(na.color)
+        , layer.name = layer.name
+      )
+    }
+    if (is.null(clrs)) {
+      legend = mapviewLegend(values = as.vector(layer),
+                             colors = col.regions,
+                             at = at,
+                             na.color = col2Hex(na.color),
+                             layer.name = layer.name)
+    }
 
     m = legend(m)
 
@@ -289,6 +304,16 @@ leaflet_stars = function(x,
   m = leafem::addMouseCoordinates(m)
   m = leafem::addCopyExtent(m)
   if (homebutton) m = leafem::addHomeButton(m, ext, group = layer.name)
+
+  if (hide) {
+    m = leaflet::hideGroup(m, layer.name)
+  }
+
+  m$dependencies = c(
+    m$dependencies
+    , mapviewCSSDependencies()
+  )
+
   out = new('mapview', object = list(x), map = m)
   return(out)
 }
