@@ -1,15 +1,15 @@
 #' Red-Green-Blue map view of a multi-layered Raster object
 #'
 #' @description
-#' Make a Red-Green-Blue plot based on three layers (in a RasterBrick, RasterStack or stars).
+#' Make a Red-Green-Blue plot based on three layers (in a RasterBrick, RasterStack).
 #' Three layers (sometimes referred to as "bands" because they may represent
 #' different bandwidths in the electromagnetic spectrum) are combined such
 #' that they represent the red, green and blue channel. This function can
 #' be used to make 'true (or false) color images' from Landsat and other
-#' multi-band satellite images. Note, this text is plagirized, i.e. copied
+#' multi-band satellite images. Note, this text is plagiarized, i.e. copied
 #' from \code{\link{plotRGB}}.
 #'
-#' @param x a RasterBrick, RasterStack or stars
+#' @param x a RasterBrick, RasterStack
 #' @param r integer. Index of the Red channel/band, between 1 and nlayers(x)
 #' @param g integer. Index of the Green channel/band, between 1 and nlayers(x)
 #' @param b integer. Index of the Blue channel/band, between 1 and nlayers(x)
@@ -61,8 +61,8 @@ viewRGB = function(x, r = 3, g = 2, b = 1,
                     method = c("bilinear", "ngb"),
                     ...) {
 
-  if(!inherits(x, "Raster") & !inherits(x, "stars")) {
-    stop("'x' must be a Raster* or stars object.")
+  if(!inherits(x, "Raster")) { # & !inherits(x, "stars")) {
+    stop("'x' must be a Raster* object.") # or stars object.")
   }
 
   if (is.null(layer.name)) layer.name = makeLayerName(x, zcol = NULL, up = 1)
@@ -82,12 +82,16 @@ viewRGB = function(x, r = 3, g = 2, b = 1,
 
   ext = createExtent(x)
 
+  maxbytes = mapviewGetOption("raster.size")
+
   m = leafem::addRasterRGB(map = m, x = x, r = r, g = g, b = b,
-                            quantiles = quantiles,
-                            # maxpixels = maxpixels,
-                            na.color = na.color,
-                            method = method,
-                            group = grp)
+                           quantiles = quantiles,
+                           # maxpixels = maxpixels,
+                           na.color = na.color,
+                           method = method,
+                           group = grp,
+                           maxBytes = maxbytes,
+                           ...)
   m = mapViewLayersControl(map = m,
                             map.types = map.types,
                             names = grp)
